@@ -1,8 +1,16 @@
+__all__ = (
+    "SpotifyRequestException",
+    "InvalidSpotifyURL",
+)
+
+
 class SpotifyRequestException(Exception):
     """An error occurred when making a request to the Spotify API"""
+
     pass
 
 
 class InvalidSpotifyURL(Exception):
     """An invalid Spotify URL was passed"""
+
     pass
